@@ -38,6 +38,24 @@ from Fishconsole import houtai
 # 导入强制更新系统所需要的内容
 
 
+def cmd命令(命令,颜色:str=None):
+    import os
+    from Fishconsole import files,logs
+    if files.强制类型检测(命令,["str"]) and files.强制类型检测(颜色,["str","NoneType"]):
+        result = os.popen(命令)
+        res = result.read()
+        target=""
+        count=0
+        for line in res.splitlines():
+            if count==0:
+                target=line
+            else:
+                target = target + "\n" + line
+            count+=1
+        return logs.颜色(target,颜色)
+    else:
+        print(logs.安全退出("请指定str类型的数据源"))
+
 def list去重(数据源):
     """
     Fishconsole list去重
@@ -334,7 +352,7 @@ def Fishconsole_Update():
 
                     print(logs.日志(f"》Fishconsole强制更新系统{fcv.version()}》Fishsys 》您的版本过低，我们将尝试自动为您更新", "红色"))
                     # 最原始的操作，大家引以为戒
-                    # os.remove("Fishconsole.fcc")
+                    # os.remove("Fishconsole")
                     系统日志(f"fup is {fup}", "强制更新系统", UPI)
                     try:
                         os.system("python.exe -m pip install --upgrade pip -i https://pypi.douban.com/simple")
@@ -969,23 +987,6 @@ def 密码(模式, 原文, 密码: str = ""):
 # b = password(2, 3, a)
 
 
-def 排名(数据源: list, 第几个: int):
-
-    from Fishconsole import files
-
-    b = files.强制类型检测(数据源, ["list"])
-    if b:
-        第几个 = int(第几个)
-        第几个 = 第几个 - 1
-        a = 数据源
-        for i in range(len(a)):
-            for j in range(0, len(a) - 1):
-                if a[j] > a[j + 1]:
-                    a[j], a[j + 1] = a[j + 1], a[j]
-        return a[第几个]
-    else:
-        logs.安全退出("Fishsys》排名》强制类型检测》请指定list类型的数据源")
-
 
 def 字符转unicode(模式, 原文: str):
     """
@@ -1199,85 +1200,6 @@ def 邮件发送(
         print(logs.日志("Fishsys邮件发送》官网连接失败》邮件发送失败", "红色"))
 
 
-def 数字字母化(模式, 数据源):
-    from Fishconsole import files
-    模式 = str(模式)
-    if 模式 == "1":
-        强制类型检测 = files.强制类型检测(数据源, ["int"])
-        if 强制类型检测:
-            空容器 = ""
-            数据源 = list(str(数据源))
-            for a in 数据源:
-                if a == "0":
-                    空容器 = 空容器 + "A"
-                if a == "1":
-                    空容器 = 空容器 + "B"
-                if a == "2":
-                    空容器 = 空容器 + "C"
-                if a == "3":
-                    空容器 = 空容器 + "D"
-                if a == "4":
-                    空容器 = 空容器 + "E"
-                if a == "5":
-                    空容器 = 空容器 + "F"
-                if a == "6":
-                    空容器 = 空容器 + "G"
-                if a == "7":
-                    空容器 = 空容器 + "H"
-                if a == "8":
-                    空容器 = 空容器 + "I"
-                if a == "9":
-                    空容器 = 空容器 + "J"
-                return 空容器
-        else:
-            logs.安全退出("类型错误")
-    if 模式 == "2":
-        空容器 = ""
-        强制类型检测 = files.强制类型检测(数据源, ["str"])
-        if 强制类型检测:
-            数据源 = list(str(数据源))
-            计数器 = 0
-            计数器a = 0
-            for _ in 数据源:
-                计数器a = 计数器a + 1
-            for a in 数据源:
-                if a == "A":
-                    计数器 = 计数器 + 1
-                    空容器 = 空容器 + "0"
-                if a == "B":
-                    计数器 = 计数器 + 1
-                    空容器 = 空容器 + "1"
-                if a == "C":
-                    计数器 = 计数器 + 1
-                    空容器 = 空容器 + "2"
-                if a == "D":
-                    计数器 = 计数器 + 1
-                    空容器 = 空容器 + "3"
-                if a == "E":
-                    计数器 = 计数器 + 1
-                    空容器 = 空容器 + "4"
-                if a == "F":
-                    计数器 = 计数器 + 1
-                    空容器 = 空容器 + "5"
-                if a == "G":
-                    计数器 = 计数器 + 1
-                    空容器 = 空容器 + "6"
-                if a == "H":
-                    计数器 = 计数器 + 1
-                    空容器 = 空容器 + "7"
-                if a == "I":
-                    计数器 = 计数器 + 1
-                    空容器 = 空容器 + "8"
-                if a == "J":
-                    计数器 = 计数器 + 1
-                    空容器 = 空容器 + "9"
-                if 计数器 == 计数器a:
-                    return 空容器
-                else:
-                    logs.安全退出("数据源错误")
-        else:
-            logs.安全退出("类型错误")
-        return 数据源
 
 
 def 任务平均分配(任务数量, 数据源: list):
@@ -1354,7 +1276,6 @@ def 进程存活性检测(pid):
     return False
 
 
-
 def 随机IP代理():
     from Fishconsole import files
     if 进程存活性检测(files.缓存(2,文件名="C:\Fishconsole\programes\Tempfiles\houtai_core.fcc",变量名="ipmadomPid")):
