@@ -16,7 +16,7 @@ try:
 
         :return: 返回版本号
         """
-        return '3.5.8'
+        return '3.5.55'
 
 
     def f_debug():
@@ -161,11 +161,11 @@ try:
                         res = pd.merge(res, 变量组classification)
                         try:
 
-                            with pd.ExcelWriter(r'Fishconsole.fcc.xlsx') as writer:
+                            with pd.ExcelWriter(r'Fishconsole.xlsx') as writer:
                                 to_excel_auto_column_weight(res, writer, f'Fishconsole fcv_debug变量组')
 
                             def start():
-                                os.system("Fishconsole.fcc.xlsx")
+                                os.system("Fishconsole.xlsx")
 
                             a = threading.Thread(target=start)
                             a.start()
@@ -408,7 +408,7 @@ try:
                 threading.Thread(target=temp).start()
 
 
-            elif b[0] in ["execute"]:
+            elif b[0] in ["execute","EXECUTE"]:
                 未选触发器 = True
                 空容器 = ""
                 计数器 = 0
@@ -426,8 +426,9 @@ try:
                     print("语法就是 execute + 系统指令")
 
 
-            elif b[0] in ["turn", "turn"]:
+            elif b[0] in ["turn", "TURN"]:
                 未选触发器 = True
+                文件名 = "C:\\Fishconsole\\programes\\Tempfiles\\houtai_core.fcc"
                 for a in b:
                     # 循环检测
 
@@ -435,40 +436,41 @@ try:
                         for a in b:
                             if a in ['on','ON']:
                                 print('turn on file_protect')
-                                if files.文件存在性检测('C:\\Fishconsole\\programes\\Tempfiles\\houtai_core.fcc'):
-                                    files.缓存(3,文件名='C:\\Fishconsole\\programes\\Tempfiles\\houtai_core.fcc',数据={'file_protect':True})
+
+                                if files.文件存在性检测(文件名):
+                                    files.缓存(3,文件名=文件名,数据={'file_protect':True})
                                 else:
-                                    print('文件不存在，新建')
-                                    files.缓存(1, 文件名='C:\\Fishconsole\\programes\\Tempfiles\\houtai_core.fcc',数据={'file_protect': True})
+                                    print('文件不存在，新建a')
+                                    files.缓存(3, 文件名=文件名,数据={'file_protect': True})
                                 未选触发器 = False
                                 break
                             elif a in ['off','OFF']:
                                 print('turn off file_protect')
-                                if files.文件存在性检测('C:\\Fishconsole\\programes\\Tempfiles\\houtai_core.fcc'):
-                                    files.缓存(3,文件名='C:\\Fishconsole\\programes\\Tempfiles\\houtai_core.fcc',数据={'file_protect':False})
+                                if files.文件存在性检测(文件名):
+                                    files.缓存(3,文件名=文件名,数据={'file_protect':False})
                                 else:
-                                    print('文件不存在，新建')
-                                    files.缓存(1, 文件名='C:\\Fishconsole\\programes\\Tempfiles\\houtai_core.fcc',数据={'file_protect': False})
+                                    print('文件不存在，新建b')
+                                    files.缓存(3, 文件名=文件名,数据={'file_protect': False})
                                 未选触发器 = False
                                 break
                     if a in ['ipmadom','IPMADOM']:
                         for a in b:
                             if a in ['on','ON']:
                                 print('turn on ipmadom')
-                                if files.文件存在性检测('C:\\Fishconsole\\programes\\Tempfiles\\houtai_core.fcc'):
-                                    files.缓存(3,文件名='C:\\Fishconsole\\programes\\Tempfiles\\houtai_core.fcc',数据={'ipmadom':True})
+                                if files.文件存在性检测(文件名):
+                                    files.缓存(3,文件名=文件名,数据={'ipmadom':True})
                                 else:
-                                    print('文件不存在，新建')
-                                    files.缓存(1, 文件名='C:\\Fishconsole\\programes\\Tempfiles\\houtai_core.fcc',数据={'ipmadom': True})
+                                    print('文件不存在，新建c')
+                                    files.缓存(3, 文件名=文件名,数据={'ipmadom': True})
                                 未选触发器 = False
                                 break
                             elif a in ['off','OFF']:
-                                print('turn off file_protect')
-                                if files.文件存在性检测('C:\\Fishconsole\\programes\\Tempfiles\\houtai_core.fcc'):
-                                    files.缓存(3,文件名='C:\\Fishconsole\\programes\\Tempfiles\\houtai_core.fcc',数据={'ipmadom':False})
+                                print('turn off ipmadom')
+                                if files.文件存在性检测(文件名):
+                                    files.缓存(3,文件名=文件名,数据={'ipmadom':False})
                                 else:
-                                    print('文件不存在，新建')
-                                    files.缓存(1, 文件名='C:\\Fishconsole\\programes\\Tempfiles\\houtai_core.fcc',数据={'ipmadom': False})
+                                    print('文件不存在，新建d')
+                                    files.缓存(3, 文件名=文件名,数据={'ipmadom': False})
                                 未选触发器 = False
                                 break
 
@@ -485,6 +487,126 @@ try:
                     print('语法是：turn+关键字on/off+关键字可用后台')
                     print("如果想了解具体的用法，请在终端中键入'help'或者'?'")
 
+            elif b[0] in ['test','TESR']:
+                未选触发器 = True
+                for a in b:
+                    # 循环检测
+
+                    if a in ['speed','SPEED']:
+
+                        from Fishconsole import Fishsys, files, logs
+                        import time
+
+                        list_data = [0] * 4000000
+                        str_data = "a" * 4000000
+                        number_show = 7
+
+                        def testtime(a):
+                            start_time = time.time()
+                            exec(a)
+                            end_time = time.time()
+                            return round(end_time - start_time, number_show)
+
+                        def fishsys_test():
+                            print(logs.分割线("Fishconsole 模块包速率检测", "Fishsys", "蓝色"))
+                            all_time = 0
+
+                            time = testtime(f"""
+from Fishconsole import Fishsys
+Fishsys.list去重({list_data})
+                            """)                                                                                                             # Fishsys.list去重项
+                            all_time += time
+                            print(logs.日志(f"Fishsys.list去重的运行时间为{time}", "蓝色"))
+
+
+                            time = testtime(f"""
+from Fishconsole import Fishsys
+Fishsys.任务平均分配('40',{list_data})
+                            """)                                                                                                             # Fishsys.任务平均分配
+                            all_time += time
+                            print(logs.日志(f"Fishsys.任务平均分配的运行时间为{time}", "蓝色"))
+
+
+
+                            time = testtime(f"""
+from Fishconsole import Fishsys
+Fishsys.密码(1,'{str_data}')
+                            """)                                                                                                              # Fishsys.密码
+                            all_time += time
+                            print(logs.日志(f"Fishsys.密码的运行时间为{time}", "蓝色"))
+
+                            time = testtime(f"""
+from Fishconsole import Fishsys
+Fishsys.字符转unicode(1,'{str_data}')
+                        """)                                                                                                                                                    # Fishsys.字符转unicode
+
+                            all_time += time
+                            print(logs.日志(f"Fishsys.字符转unicode的运行时间为{time}", "蓝色"))
+
+                            del time
+                            return all_time
+
+                        def logs_test():
+                            print(logs.分割线("Fishconsole 模块包速率检测", "logs", "蓝色"))
+                            all_time = 0
+
+                            time = testtime(f"""
+from Fishconsole import logs
+logs.变量查看(变量名='temp',变量='{str_data}',models='fcv')
+                            """)                                                                                                                                                # logs.变量查看
+                            all_time += time
+                            print(logs.日志(f"logs.变量查看的运行时间为{time}", "蓝色"))
+
+                            del time
+                            return all_time
+
+                        def User_Fishconsole_Speedtest(模式):
+                            if files.强制类型检测(模式, ["str"]):
+                                if 模式 == "Fishsys":
+                                    return round(fishsys_test(), number_show)
+                                elif 模式 == "logs":
+                                    return round(logs_test(), number_show)
+                                elif 模式 == "all":
+                                    all_time = 0
+                                    all_time += fishsys_test()
+                                    all_time += logs_test()
+                                    return round(all_time, number_show)
+                                else:
+                                    return logs.日志("目前的可用模式只有Fishsys,all", "红色")
+                            else:
+                                return logs.日志("请指定正确的数据源", "红色")
+
+
+
+                        for a in b:
+                            if a in ['Fishsys']:
+                                未选触发器 = False
+                                print(logs.日志(f'Fishsys基于计算的服务速度检测完毕，耗时：{User_Fishconsole_Speedtest("Fishsys")}',色选="绿色"))
+                                break
+                            elif a in ['logs']:
+                                未选触发器 = False
+                                print(logs.日志(f'logs基于计算的服务速度检测完毕，耗时：{User_Fishconsole_Speedtest("logs")}', 色选="绿色"))
+                                break
+                            elif a in ['all']:
+                                未选触发器 = False
+                                print(logs.日志(f'基于计算的服务速度检测完毕，耗时：{User_Fishconsole_Speedtest("all")}', 色选="绿色"))
+                                break
+
+
+
+                if 未选触发器:
+                    print(logs.分割线(f"这是test的简介", "fcv_debug console", 色选="红色"))
+                    print("他的作用就是对测试Fishconsole模块包的部分很耗时间的代码进行测试，这样可以验证算法的更新是否提高了速度")
+                    print('------------------')
+                    print('可用模式有：')
+                    print('test speed Fishsys')
+                    print('test speed logs')
+                    print('test speed all')
+                    print('------------------')
+                    print("如果想了解具体的用法，请在终端中键入'help'或者'?'")
+
+
+
             else:
                 print(logs.日志(f"‘{b[0]}’是不受支持的命令，如果想查看命令，请键入'help'或者'?'", 色选="红色"))
 
