@@ -43,6 +43,20 @@ try:
                     Fishconsole_logo.write(res)
             except:
                 pass
+                
+        try:
+            Fishconsole_logo_ico = open("C:\Fishconsole\img\Fishconsole.ico", "rb")
+            Fishconsole_logo_ico.read()
+        except:
+            print("文件未找到，程序将会自动下载")
+            try:
+                res = requests.get("https://pic.stackoverflow.wiki/uploadImages/106/84/2/238/2022/08/04/23/28/5a0618d5-d8c9-4fd5-bc8a-be963cb19ca0.ico").content
+                with open("C:\Fishconsole\img\Fishconsole.ico", "wb+") as Fishconsole_logo_ico:
+                    Fishconsole_logo_ico.write(res)
+            except:
+                pass
+                
+                
 
         try:
             houtai_core = open("C:\Fishconsole\programes\Tempfiles\houtai_core.fcc", "r")
@@ -55,6 +69,10 @@ try:
             ipCore.read()
         except:
             pass
+        
+            
+
+
 
 
 
@@ -79,10 +97,10 @@ except KeyboardInterrupt:
     代理池 =\
 r'''
 
-
 import os
 from Fishconsole import logs
 pid =os.getpid()
+os.system('cls')
 print(logs.日志(f'Fishconsole 随机ip代理池启动{pid}' ,'绿色'))
 
 try:
@@ -105,6 +123,7 @@ try:
                         break
 
 
+
                     res = requests.get(f'https://free.kuaidaili.com/free/inha/{str(计数器)}').text
 
                     res = etree.HTML(res)
@@ -328,10 +347,13 @@ try:
         from Fishconsole import logs ,files ,Fishsys
         import multiprocessing
         import time
+        import  os
 
-
-
+                
+        本进程的pid=os.getpid()
         缓存文件名 = 'C:\Fishconsole\programes\Tempfiles\houtai_core.fcc'
+        from Fishconsole import files
+        files.缓存(3,文件名=缓存文件名,数据={'ipmadomPid':本进程的pid})
 
         print('loading..25%')
         爬虫进程回调 = multiprocessing.Queue()
@@ -347,6 +369,7 @@ try:
         print('loading..100%')
         爬虫进程启动器.join()
         验证进程启动器.join()
+        
 except KeyboardInterrupt:
     from Fishconsole import logs
     from Fishconsole import files
@@ -355,13 +378,27 @@ except KeyboardInterrupt:
 
 
 
-
  '''
 
-    start = """start python  C:\Fishconsole\programes\Management\Management.py"""
+    start = """
+start pythonw  C:\Fishconsole\programes\Management\Management.py
+    """
 
     后台管理器='''
     
+
+
+
+
+    
+
+
+    
+
+    
+import os
+os.system("cls")
+    
 try:
     from Fishconsole import Fishsys
 
@@ -370,7 +407,7 @@ try:
         import sys
         import  os
         本进程的pid=os.getpid()
-        缓存文件名 = 'C:\\Fishconsole\\programes\\Tempfiles\\houtai_core.fcc'
+        缓存文件名 = 'C:\Fishconsole\programes\Tempfiles\houtai_core.fcc'
         from Fishconsole import files
         files.缓存(3,文件名=缓存文件名,数据={'FileprotectPid':本进程的pid})
         sys.path.append(r'C:\Fishconsole\programes\FileProtect')
@@ -384,20 +421,41 @@ try:
         import sys
         import  os
         本进程的pid=os.getpid()
-        缓存文件名 = 'C:\\Fishconsole\\programes\\Tempfiles\\houtai_core.fcc'
+        缓存文件名 = 'C:\Fishconsole\programes\Tempfiles\houtai_core.fcc'
         from Fishconsole import files
         files.缓存(3,文件名=缓存文件名,数据={'ipmadomPid':本进程的pid})
         try:
-            os.system("python C:\Fishconsole\programes\ipmadom\ipmadom.py")
+            os.system("start python C:\Fishconsole\programes\ipmadom\ipmadom.py")
         except KeyboardInterrupt:
             from Fishconsole import logs
             print(logs.日志("ipmadom安全退出","蓝色"))
+            
+    def toast(title,msg):
+            from plyer import notification
+            notification.notify(title,message=msg,app_icon = "C:\Fishconsole\img\Fishconsole.ico",timeout=15)
+
+            
+    def Noproblem_run():
+        try:
+            import time
+            from Fishconsole import logs
+            while True:
+                time.sleep(1800)
+                toast("Fishconsole 后台中心","后台管理器正在稳定运行（每1800秒自动播报）")
+        except KeyboardInterrupt:
+            from Fishconsole import logs
+            print(logs.日志("后台管理器存活报告器安全退出","蓝色"))
+
+
+
 
     if __name__ == '__main__':
         import multiprocessing
         import os
         from Fishconsole import files, logs,Fishsys
         import time
+        import threading
+
 
         # 这里有一个致命的问题，就是这个主进程没有检测其他相同进程自动关闭的东西，如果要解决这个东西，先升级强制更新系统，虽然现在似乎问题不大
         # 进程管理器的pid = os.getpid()
@@ -417,10 +475,11 @@ try:
 
 
         缓存文件名 = 'C:\Fishconsole\programes\Tempfiles\houtai_core.fcc'
+        Noproblem_run_start = threading.Thread(target=Noproblem_run)
+        Noproblem_run_start.start()
+
 
         while True:
-
-
             res=启动数据源 = files.缓存(2, 文件名=缓存文件名)
             if not res:
                 print(logs.日志("文件不存在，自动创建"))
@@ -429,42 +488,47 @@ try:
 
             # ipmadom
             if not 启动数据源  == False:
-               def __启动():
+               def __启动(model):
                    res = multiprocessing.Process(target=ipmadom)
                    res.start()
-                   print(logs.日志(f'ipmadom进程已启动a - ({res.pid}) ({res.name})', '红色'))
+                   toast("Fishconsole 后台中心","ipmadom已启动")
+
+
+                   print(logs.日志(f'ipmadom进程已启动{model} - ({res.pid}) ({res.name})', '红色'))
                try:
                    if 启动数据源['ipmadom']:
                        try:
                            pid=files.缓存(2,文件名=缓存文件名,变量名='ipmadomPid')
                            if not Fishsys.进程存活性检测(pid):
-                               __启动()
+                               __启动("a")
                            else:
                                print(logs.日志('ipmadom进程正在运行','绿色'))
                        except:
                            print(logs.日志('未检测到ipmadom初始pid，直接启动'))
-                           __启动()
+                           __启动("b")
                except KeyError:
-                   print(logs.日志("缓存为空，可能是被重置，直接启动"))
-                   try:
-                       pid = files.缓存(2, 文件名=缓存文件名, 变量名='ipmadomPid')
-                       if not Fishsys.进程存活性检测(pid):
-                           __启动()
-                       else:
-                           print(logs.日志('ipmadom进程正在运行', '绿色'))
-                   except:
-                       print('未检测到ipmadom初始pid，直接启动')
-                       __启动()
+                   # print(logs.日志("缓存为空，可能是被重置，直接启动"))
+                   # try:
+                   #     pid = files.缓存(2, 文件名=缓存文件名, 变量名='ipmadomPid')
+                   #     if not Fishsys.进程存活性检测(pid):
+                   #         __启动("c")
+                   #     else:
+                   #         print(logs.日志('ipmadom进程正在运行', '绿色'))
+                   # except:
+                       pass
             if not 启动数据源 == False:
                try:#没有文件根它没关系
                    if not 启动数据源['ipmadom']:
                        #检测到fcv_debug要关闭时就关闭
                        pid = files.缓存(2, 文件名=缓存文件名, 变量名='ipmadomPid')
-                       if not Fishsys.进程存活性检测(pid):
-                           print(logs.日志('ipmadom进程不存在','蓝色'))
-                       else:
-                           print(logs.日志('ipmadom进程已被杀死', '红色'))
-                           os.system(f'taskkill /pid {pid}  -t  -f')
+                       if pid!="error":
+                            if not Fishsys.进程存活性检测(pid):
+                                print(logs.日志('ipmadom进程不存在','蓝色'))
+                            else:
+
+                                toast("Fishconsole 后台中心","ipmadom已关闭")
+                                print(logs.日志('ipmadom进程已被杀死', '红色'))
+                                os.system(f'taskkill /pid {pid}  -t  -f')
                except KeyError:
                    pass
 
@@ -473,6 +537,7 @@ try:
                def __启动():
                    res = multiprocessing.Process(target=file_protect)
                    res.start()
+                   toast("Fishconsole 后台中心","File_Protect已启动")
                    print(logs.日志(f'file_protect进程已启动a - ({res.pid}) ({res.name})', '红色'))
                try:
                    if 启动数据源['file_protect']:
@@ -501,13 +566,18 @@ try:
                    if not 启动数据源['file_protect']:
                        #检测到fcv_debug要关闭时就关闭
                        pid = files.缓存(2, 文件名=缓存文件名, 变量名='FileprotectPid')
-                       if not Fishsys.进程存活性检测(pid):
-                           print(logs.日志('file_protect进程不存在','蓝色'))
-                       else:
-                           print(logs.日志('file_protect进程已被杀死', '红色'))
-                           os.system(f'taskkill /pid {pid}  -t  -f')
+                       if pid!="error":
+                            if not Fishsys.进程存活性检测(pid):
+                                print(logs.日志('file_protect进程不存在','蓝色'))
+                            else:
+                                toast("Fishconsole 后台中心","File_Protect已关闭")
+                                print(logs.日志('file_protect进程已被杀死', '红色'))
+                                os.system(f'taskkill /pid {pid}  -t  -f')
                except KeyError:
                    pass
+                
+                
+            
 
 
 
@@ -524,9 +594,23 @@ try:
 
 except KeyboardInterrupt:
     from Fishconsole import logs
+    print(Fishsys.cmd命令(f"taskkill /pid {files.缓存(2,文件名=缓存文件名,变量名='ipmadomPid')}","蓝色"))
     print(logs.日志('Fishconsole Main 已安全退出','蓝色'))
 
     
+    
+
+    
+    
+    
+    
+    
+    
+    
+    
+    
+    
+    
     '''
 
     os.makedirs('C:\Fishconsole\programes\FileProtect', exist_ok=True)
@@ -554,6 +638,8 @@ except KeyboardInterrupt:
         f.close()
 
 
+
+
 except KeyboardInterrupt:
     from Fishconsole import logs
     print(logs.日志('Fishconsole Houtai 已安全退出','蓝色'))
\ No newline at end of file
