@@ -133,7 +133,7 @@ def 分割线(标题, text, 色选="Nona"):
 
 
 
-def 变量查看(变量名: str, 变量, 色选: str = "红色"):
+def 变量查看(变量名: str, 变量, 色选: str = "红色",models=None):
     """
     FishCosnole LOGS 变量查看模块
 
@@ -173,19 +173,20 @@ def 变量查看(变量名: str, 变量, 色选: str = "红色"):
     if 计数器>=100:
         计数器=100
 
-    print("=" * 计数器+"\n"+日志(f"  ||（{颜色('名字', 色选)}：{变量名}）")+"\n"+日志(f"  ||（{颜色('类型', 色选)}: {变量类型}）"))
-    if 变量类型 in ["numpy.ndarray","torch.Tensor","pandas.core.frame.DataFrame"]:
-        print(日志(f"  ||（{颜色('数据', 色选)}：\n{变量}\n）"))
-    else:
-        print(日志(f"  ||（{颜色('数据', 色选)}：{变量}）"))
-    print(日志(f"  ||（{颜色('位置', 色选)}: {行位置}）"))
+    if models  == None:
+        print("=" * 计数器+"\n"+日志(f"  ||（{颜色('名字', 色选)}：{变量名}）")+"\n"+日志(f"  ||（{颜色('类型', 色选)}: {变量类型}）"))
+        if 变量类型 in ["numpy.ndarray","torch.Tensor","pandas.core.frame.DataFrame"]:
+            print(日志(f"  ||（{颜色('数据', 色选)}：\n{变量}\n）"))
+        else:
+            print(日志(f"  ||（{颜色('数据', 色选)}：{变量}）"))
+        print(日志(f"  ||（{颜色('位置', 色选)}: {行位置}）"))
 
-    try:
-        print(日志(f"  ||（{颜色('编码', 色选)}: {chardet.detect(变量)['encoding']} / {chardet.detect(变量)['confidence']}）"))
-    except:
-        print(日志(f"  ||（{颜色('编码', 色选)}: 未知 / 未知）"))
+        try:
+            print(日志(f"  ||（{颜色('编码', 色选)}: {chardet.detect(变量)['encoding']} / {chardet.detect(变量)['confidence']}）"))
+        except:
+            print(日志(f"  ||（{颜色('编码', 色选)}: 未知 / 未知）"))
 
-    print("=" * 计数器 + "\n\n")
+        print("=" * 计数器 + "\n\n")
 
 
 
@@ -210,6 +211,87 @@ def 安全退出(内容, 变量=None):
 
         sys.exit(日志(f"》Fishconsole {fcv.version()}安全退出》{内容} || line[{a}] ", "红色"))
 
+def windows系统通知(标题:str,内容:str,选项:str="确定"):
+    """
+    FishConsole windows系统通知
+    
+   ----
+   
+   - 原来的win32api所带来的系统通知返回值很乱，这边统一了一下，只有一个选项的将会以多线程的形式呈现，不会打扰到程序的运行
+   
+   
+   - 使用多线程的项目：
+   
+    提醒（是）
+    
+    警告（是）
+    
+    提示（是）
+    
+    确认（否）
+    
+    重试（否）
+    
+    双选提醒（否）
+    
+    疑问（否）
+    
+    
+    :param 标题: 标题，需要str类型
+    :param 内容: 内容，需要str类型
+    :param 选项: 选项名，需要str类型
+    :return:  双选返回布尔值，是为True，单选返回None
+    """
+    import win32api
+    import win32con
+    from Fishconsole import  files
+    import threading
+    if files.强制类型检测(标题,["str"]) and files.强制类型检测(内容,["str"]) and files.强制类型检测(选项,["str"]):
+        if 选项=="提醒":
+            def a():
+                win32api.MessageBox(0, f"{内容}", f"{标题}", win32con.MB_OK)
+            res=threading.Thread(target=a,daemon=True)
+            res.start()
+
+
+        if 选项 == "双选提醒":
+            a=win32api.MessageBox(0,f"{内容}", f"{标题}", win32con.MB_YESNO)
+            if a==6:
+                return True
+            else:
+                return False
+
+        if 选项 == "警告":
+            def a():
+                win32api.MessageBox(0, f"{内容}", f"{标题}", win32con.MB_ICONWARNING)
+            res=threading.Thread(target=a,daemon=True)
+            res.start()
+
+        if 选项 == "疑问":
+            def a():
+                win32api.MessageBox(0, "这是一个测试疑问信息框", f"{标题}", win32con.MB_ICONQUESTION)
+            res=threading.Thread(target=a,daemon=True)
+            res.start()
+
+        if 选项 == "提示":
+            def a():
+                win32api.MessageBox(0, f"{内容}", f"{标题}", win32con.MB_ICONASTERISK)
+            res=threading.Thread(target=a,daemon=True)
+            res.start()
+
+        if 选项 == "确认":
+            a=win32api.MessageBox(0, f"{内容}", f"{标题}", win32con.MB_OKCANCEL)
+            if a==1:
+                return True
+            else:
+                return False
+
+        if 选项 == "重试":
+             a=win32api.MessageBox(0, f"{内容}", f"{标题}", win32con.MB_RETRYCANCEL)
+             if a==4:
+                 return True
+             else:
+                 return False
 
 # print(日志(123, 色选="红色"))
 # print(分割线("123","456","红色"))
